CounterName

Enum CounterName 

pub enum CounterName {
Show 98 variants ComponentReceivedEventsTotal, ComponentReceivedEventBytesTotal, ComponentReceivedBytesTotal, ComponentSentEventsTotal, ComponentSentEventBytesTotal, ComponentSentBytesTotal, ComponentDiscardedEventsTotal, ComponentErrorsTotal, ComponentTimedOutEventsTotal, ComponentTimedOutRequestsTotal, BufferReceivedEventsTotal, BufferReceivedBytesTotal, BufferSentEventsTotal, BufferSentBytesTotal, BufferDiscardedEventsTotal, BufferDiscardedBytesTotal, BufferErrorsTotal, AggregateEventsRecordedTotal, AggregateFailedUpdates, AggregateFlushesTotal, ApiStartedTotal, CheckpointsTotal, ChecksumErrorsTotal, CollectCompletedTotal, CommandExecutedTotal, ConnectionEstablishedTotal, ConnectionSendErrorsTotal, ConnectionShutdownTotal, ContainerProcessedEventsTotal, ContainersUnwatchedTotal, ContainersWatchedTotal, DecoderBomRemovalsTotal, DecoderMalformedReplacementWarningsTotal, DorisBytesLoadedTotal, DorisRowsFilteredTotal, DorisRowsLoadedTotal, EncoderUnmappableReplacementWarningsTotal, EventsDiscardedTotal, FilesAddedTotal, FilesDeletedTotal, FilesResumedTotal, FilesUnwatchedTotal, GrpcServerMessagesReceivedTotal, GrpcServerMessagesSentTotal, HttpClientErrorsTotal, HttpClientRequestsSentTotal, HttpClientResponsesTotal, HttpServerRequestsReceivedTotal, HttpServerResponsesSentTotal, KafkaConsumedMessagesBytesTotal, KafkaConsumedMessagesTotal, KafkaProducedMessagesBytesTotal, KafkaProducedMessagesTotal, KafkaRequestsBytesTotal, KafkaRequestsTotal, KafkaResponsesBytesTotal, KafkaResponsesTotal, MetadataRefreshFailedTotal, MetadataRefreshSuccessfulTotal, ParseErrorsTotal, QuitTotal, ReloadedTotal, RewrittenTimestampEventsTotal, SqsMessageDeferSucceededTotal, SqsMessageDeleteSucceededTotal, SqsMessageProcessingSucceededTotal, SqsMessageReceiveSucceededTotal, SqsMessageReceivedMessagesTotal, StaleEventsFlushedTotal, StartedTotal, StoppedTotal, TagCardinalityUntrackedEventsTotal, TagValueLimitExceededTotal, ValueLimitReachedTotal, WebsocketBytesSentTotal, WebsocketMessagesSentTotal, WindowsServiceInstallTotal, WindowsServiceRestartTotal, WindowsServiceStartTotal, WindowsServiceStopTotal, WindowsServiceUninstallTotal, K8sEventNamespaceAnnotationFailuresTotal, K8sEventNodeAnnotationFailuresTotal, K8sFormatPickerEdgeCasesTotal, K8sDockerFormatParseFailuresTotal, SqsS3EventRecordIgnoredTotal, ComponentAllocatedBytesTotal, ComponentDeallocatedBytesTotal, MemoryEnrichmentTableFailedInsertions, MemoryEnrichmentTableFailedReads, MemoryEnrichmentTableFlushesTotal, MemoryEnrichmentTableInsertionsTotal, MemoryEnrichmentTableReadsTotal, MemoryEnrichmentTableTtlExpirations, ConnectionReadErrorsTotal, InternalMetricsCardinalityTotal, ConfigReloadRejected, Utf8ConvertErrorsTotal,
}
Canonical list of all per-component internal counter metric names emitted by Vector.

Variants



ComponentReceivedEventsTotal

The number of events accepted by this component either from tagged origins like file and uri, or cumulatively from other origins.



ComponentReceivedEventBytesTotal

The number of event bytes accepted by this component either from tagged origins like file and uri, or cumulatively from other origins.



ComponentReceivedBytesTotal

The number of raw bytes accepted by this component from source origins.



ComponentSentEventsTotal

The total number of events emitted by this component.



ComponentSentEventBytesTotal

The total number of event bytes emitted by this component.



ComponentSentBytesTotal

The number of raw bytes sent by this component to destination sinks.



ComponentDiscardedEventsTotal

The number of events dropped by this component.



ComponentErrorsTotal

The total number of errors encountered by this component.



ComponentTimedOutEventsTotal

The total number of events for which this source responded with a timeout error.



ComponentTimedOutRequestsTotal

The total number of requests for which this source responded with a timeout error.



BufferReceivedEventsTotal

The number of events received by this buffer.



BufferReceivedBytesTotal

The number of bytes received by this buffer.



BufferSentEventsTotal

The number of events sent by this buffer.



BufferSentBytesTotal

The number of bytes sent by this buffer.



BufferDiscardedEventsTotal

The number of events dropped by this buffer.



BufferDiscardedBytesTotal

The number of bytes dropped by this buffer.



BufferErrorsTotal

The total number of buffer errors encountered.



AggregateEventsRecordedTotal

The number of events recorded by the aggregate transform.



AggregateFailedUpdates

The number of failed metric updates, incremental adds, encountered by the aggregate transform.



AggregateFlushesTotal

The number of flushes done by the aggregate transform.



ApiStartedTotal

The number of times the Vector API has been started.



CheckpointsTotal

The total number of files checkpointed.



ChecksumErrorsTotal

The total number of errors identifying files via checksum.



CollectCompletedTotal

The total number of metrics collections completed for this component.



CommandExecutedTotal

The total number of times a command has been executed.



ConnectionEstablishedTotal

The total number of times a connection has been established.



ConnectionSendErrorsTotal

The total number of errors sending data via the connection.



ConnectionShutdownTotal

The total number of times the connection has been shut down.



ContainerProcessedEventsTotal

The total number of container events processed.



ContainersUnwatchedTotal

The total number of times Vector stopped watching for container logs.



ContainersWatchedTotal

The total number of times Vector started watching for container logs.



DecoderBomRemovalsTotal

The total number of byte order marks (BOM) removed from incoming data.



DecoderMalformedReplacementWarningsTotal

The total number of warnings when replacing malformed characters during decoding.



DorisBytesLoadedTotal

The total number of bytes loaded into Doris.



DorisRowsFilteredTotal

The total number of rows filtered by Doris during stream load.



DorisRowsLoadedTotal

The total number of rows successfully loaded into Doris.



EncoderUnmappableReplacementWarningsTotal

The total number of warnings when replacing unmappable characters during encoding.



EventsDiscardedTotal

The total number of events discarded by this component.



FilesAddedTotal

The total number of files Vector has found to watch.



FilesDeletedTotal

The total number of files deleted.



FilesResumedTotal

The total number of times Vector has resumed watching a file.



FilesUnwatchedTotal

The total number of times Vector has stopped watching a file.



GrpcServerMessagesReceivedTotal

The total number of gRPC messages received.



GrpcServerMessagesSentTotal

The total number of gRPC messages sent.



HttpClientErrorsTotal

The total number of HTTP client errors encountered.



HttpClientRequestsSentTotal

The total number of sent HTTP requests, tagged with the request method.



HttpClientResponsesTotal

The total number of HTTP requests, tagged with the response code.



HttpServerRequestsReceivedTotal

The total number of HTTP requests received.



HttpServerResponsesSentTotal

The total number of HTTP responses sent.



KafkaConsumedMessagesBytesTotal

Total number of message bytes (including framing) received from Kafka brokers.



KafkaConsumedMessagesTotal

Total number of messages consumed, not including ignored messages (due to offset, etc), from Kafka brokers.



KafkaProducedMessagesBytesTotal

Total number of message bytes (including framing, such as per-Message framing and MessageSet/batch framing) transmitted to Kafka brokers.



KafkaProducedMessagesTotal

Total number of messages transmitted (produced) to Kafka brokers.



KafkaRequestsBytesTotal

Total number of bytes transmitted to Kafka brokers.



KafkaRequestsTotal

Total number of requests sent to Kafka brokers.



KafkaResponsesBytesTotal

Total number of bytes received from Kafka brokers.



KafkaResponsesTotal

Total number of responses received from Kafka brokers.



MetadataRefreshFailedTotal

The total number of failed efforts to refresh AWS EC2 metadata.



MetadataRefreshSuccessfulTotal

The total number of AWS EC2 metadata refreshes.



ParseErrorsTotal

The total number of errors encountered while parsing.



QuitTotal

The total number of times the Vector instance has quit.



ReloadedTotal

The total number of times the Vector instance has been reloaded.



RewrittenTimestampEventsTotal

The total number of events whose timestamps were rewritten to maintain ordering.



SqsMessageDeferSucceededTotal

The total number of successful deferrals of SQS messages.



SqsMessageDeleteSucceededTotal

The total number of successful deletions of SQS messages.



SqsMessageProcessingSucceededTotal

The total number of SQS messages successfully processed.



SqsMessageReceiveSucceededTotal

The total number of times successfully receiving SQS messages.



SqsMessageReceivedMessagesTotal

The total number of received SQS messages.



StaleEventsFlushedTotal

The number of stale events that Vector has flushed.



StartedTotal

The total number of times the Vector instance has been started.



StoppedTotal

The total number of times the Vector instance has been stopped.



TagCardinalityUntrackedEventsTotal

The total number of events whose tag keys are no longer tracked because max_tracked_keys was reached. These events pass through the transform unchecked.



TagValueLimitExceededTotal

The total number of events discarded because the tag has been rejected after hitting the configured value_limit. When internal_metrics.include_extended_tags is enabled in the tag_cardinality_limit transform, this metric includes metric_name and tag_key labels. By default, this metric has no labels to keep cardinality low.



ValueLimitReachedTotal

The total number of times new values for a key have been rejected because the value limit has been reached.



WebsocketBytesSentTotal

The total number of bytes sent over WebSocket connections.



WebsocketMessagesSentTotal

The total number of messages sent over WebSocket connections.



WindowsServiceInstallTotal

The total number of times the Windows service has been installed.



WindowsServiceRestartTotal

The total number of times the Windows service has been restarted.



WindowsServiceStartTotal

The total number of times the Windows service has been started.



WindowsServiceStopTotal

The total number of times the Windows service has been stopped.



WindowsServiceUninstallTotal

The total number of times the Windows service has been uninstalled.



K8sEventNamespaceAnnotationFailuresTotal

The total number of failures to annotate Kubernetes events with namespace metadata.



K8sEventNodeAnnotationFailuresTotal

The total number of failures to annotate Kubernetes events with node metadata.



K8sFormatPickerEdgeCasesTotal

The total number of edge cases encountered while picking format of the Kubernetes log message.



K8sDockerFormatParseFailuresTotal

The total number of failures to parse a message as a JSON object.



SqsS3EventRecordIgnoredTotal

The total number of times an S3 record in an SQS message was ignored (for an event that was not ObjectCreated).



ComponentAllocatedBytesTotal

The total number of bytes allocated by this component.



ComponentDeallocatedBytesTotal

The total number of bytes deallocated by this component.



MemoryEnrichmentTableFailedInsertions

The total number of failed insertions into the in-memory enrichment table.



MemoryEnrichmentTableFailedReads

The total number of failed reads from the in-memory enrichment table.



MemoryEnrichmentTableFlushesTotal

The total number of flushes of the in-memory enrichment table.



MemoryEnrichmentTableInsertionsTotal

The total number of successful insertions into the in-memory enrichment table.



MemoryEnrichmentTableReadsTotal

The total number of successful reads from the in-memory enrichment table.



MemoryEnrichmentTableTtlExpirations

The total number of entries evicted from the in-memory enrichment table due to TTL expiration.



ConnectionReadErrorsTotal

The total number of errors reading datagram.



InternalMetricsCardinalityTotal

The total number of metrics emitted from the internal metrics registry. This metric is deprecated in favor of internal_metrics_cardinality.



ConfigReloadRejected

Number of configuration reload attempts that were rejected.



Utf8ConvertErrorsTotal

The total number of errors converting bytes to a UTF-8 string in UDP mode.

Implementations

Source

impl CounterName

pub const fn as_str(self) -> &'static str