GaugeName

Enum GaugeName 

pub enum GaugeName {
Show 38 variants ComponentLatencyMeanSeconds, SourceBufferMaxEventSize, SourceBufferMaxByteSize, SourceBufferMaxSizeEvents, SourceBufferMaxSizeBytes, SourceBufferUtilizationLevel, SourceBufferUtilizationMean, TransformBufferMaxEventSize, TransformBufferMaxByteSize, TransformBufferMaxSizeEvents, TransformBufferMaxSizeBytes, TransformBufferUtilizationLevel, TransformBufferUtilizationMean, BufferMaxSizeEvents, BufferMaxEventSize, BufferMaxSizeBytes, BufferMaxByteSize, BufferEvents, BufferSizeEvents, BufferSizeBytes, BufferByteSize, Utilization, ComponentAllocatedBytes, OpenFiles, UptimeSeconds, BuildInfo, KafkaQueueMessages, KafkaQueueMessagesBytes, KafkaConsumerLag, LuaMemoryUsedBytes, OpenConnections, ActiveEndpoints, SplunkPendingAcks, ActiveClients, MemoryEnrichmentTableObjectsCount, MemoryEnrichmentTableByteSize, TagCardinalityTrackedKeys, InternalMetricsCardinality,
}
Canonical list of all per-component internal gauge metric names emitted by Vector.

Variants



ComponentLatencyMeanSeconds

The mean elapsed time, in fractional seconds, that an event spends in a single transform.

This includes both the time spent queued in the transform’s input buffer and the time spent executing the transform itself. This value is smoothed over time using an exponentially weighted moving average (EWMA).



SourceBufferMaxEventSize

The maximum number of events the source buffer can hold. The outputs of the source send data to this buffer.



SourceBufferMaxByteSize

The maximum number of bytes the source buffer can hold. The outputs of the source send data to this buffer.



SourceBufferMaxSizeEvents

The maximum number of events the source buffer can hold. The outputs of the source send data to this buffer.



SourceBufferMaxSizeBytes

The maximum number of bytes the source buffer can hold. The outputs of the source send data to this buffer.



SourceBufferUtilizationLevel

The current utilization level of the source buffer. The outputs of the source send data to this buffer.



SourceBufferUtilizationMean

The mean utilization level of the source buffer. The outputs of the source send data to this buffer. The mean utilization is smoothed over time using an exponentially weighted moving average (EWMA).



TransformBufferMaxEventSize

The maximum number of events the buffer that feeds into a transform can hold.



TransformBufferMaxByteSize

The maximum number of bytes the buffer that feeds into a transform can hold.



TransformBufferMaxSizeEvents

The maximum number of events the buffer that feeds into a transform can hold.



TransformBufferMaxSizeBytes

The maximum number of bytes the buffer that feeds into a transform can hold.



TransformBufferUtilizationLevel

The current utilization level of the buffer that feeds into a transform.



TransformBufferUtilizationMean

The mean utilization level of the buffer that feeds into a transform. This value is smoothed over time using an exponentially weighted moving average (EWMA).



BufferMaxSizeEvents

The maximum number of events in the buffer.



BufferMaxEventSize

The maximum size in events that the buffer can store.



BufferMaxSizeBytes

The maximum number of bytes in the buffer.



BufferMaxByteSize

The maximum size in bytes that the buffer can store.



BufferEvents

The number of events currently in the buffer.



BufferSizeEvents

The number of events currently in the buffer.



BufferSizeBytes

The number of bytes currently in the buffer.



BufferByteSize

The number of bytes currently in the buffer.



Utilization

A ratio from 0 to 1 of the load on a component. A value of 0 would indicate a completely idle component that is simply waiting for input. A value of 1 would indicate a that is never idle. This value is updated every 5 seconds.



ComponentAllocatedBytes

The number of bytes currently allocated by this component.



OpenFiles

The total number of open files.



UptimeSeconds

The total number of seconds the Vector instance has been up.



BuildInfo

Has a fixed value of 1.0. Contains build information such as Rust and Vector versions.



KafkaQueueMessages

Current number of messages in producer queues.



KafkaQueueMessagesBytes

Current total size of messages in producer queues.



KafkaConsumerLag

The Kafka consumer lag.



LuaMemoryUsedBytes

The total memory currently being used by the Lua runtime.



OpenConnections

The number of current open connections to Vector.



ActiveEndpoints

The number of currently active endpoints.



SplunkPendingAcks

The number of outstanding Splunk HEC indexer acknowledgement acks.



ActiveClients

Number of clients attached to a component.



MemoryEnrichmentTableObjectsCount

The number of objects currently stored in the in-memory enrichment table.



MemoryEnrichmentTableByteSize

The total size in bytes of all objects stored in the in-memory enrichment table.



TagCardinalityTrackedKeys

The number of tag keys currently being tracked by the tag cardinality limit transform.



InternalMetricsCardinality

The total number of metrics emitted from the internal metrics registry.

Implementations

Source

impl GaugeName

pub const fn as_str(self) -> &'static str