pub enum HistogramName {
Show 25 variants
ComponentReceivedEventsCount,
ComponentReceivedBytes,
BufferSendDurationSeconds,
ComponentLatencySeconds,
SourceLagTimeSeconds,
SourceSendLatencySeconds,
SourceSendBatchLatencySeconds,
AdaptiveConcurrencyAveragedRtt,
AdaptiveConcurrencyBackPressure,
AdaptiveConcurrencyInFlight,
AdaptiveConcurrencyLimit,
AdaptiveConcurrencyObservedRtt,
AdaptiveConcurrencyPastRttMean,
AdaptiveConcurrencyReachedLimit,
S3ObjectProcessingSucceededDurationSeconds,
S3ObjectProcessingFailedDurationSeconds,
CollectDurationSeconds,
CommandExecutionDurationSeconds,
GrpcServerHandlerDurationSeconds,
HttpServerHandlerDurationSeconds,
HttpClientRttSeconds,
HttpClientResponseRttSeconds,
HttpClientErrorRttSeconds,
SourceBufferUtilization,
TransformBufferUtilization,
}Expand description
Canonical list of all per-component internal histogram metric names emitted by Vector.
Variants
ComponentReceivedEventsCount
A histogram of the number of events passed in each internal batch in Vector’s internal topology.
Note that this is separate than sink-level batching. It is mostly useful for low level debugging performance issues in Vector due to small internal batches.
ComponentReceivedBytes
The size in bytes of each event received by the source.
BufferSendDurationSeconds
The duration spent sending a payload to this buffer.
ComponentLatencySeconds
The elapsed time, in fractional seconds, that an event spends in a single transform.
This includes both the time spent queued in the transform’s input buffer and the time spent executing the transform itself.
SourceLagTimeSeconds
The difference between the timestamp recorded in each event and the time when it was ingested, expressed as fractional seconds.
SourceSendLatencySeconds
The time elapsed blocking on the downstream channel to accept a single chunk from a batch of events received at the source.
SourceSendBatchLatencySeconds
The time elapsed blocking on the downstream channel to accept an entire batch of events received at the source.
AdaptiveConcurrencyAveragedRtt
The average round-trip time (RTT) for the current window.
AdaptiveConcurrencyBackPressure
A boolean sample (1.0 if back pressure was observed during the current window, 0.0 otherwise).
AdaptiveConcurrencyInFlight
The number of outbound requests currently awaiting a response.
AdaptiveConcurrencyLimit
The concurrency limit that the adaptive concurrency feature has decided on for this current window.
AdaptiveConcurrencyObservedRtt
The observed round-trip time (RTT) for requests.
AdaptiveConcurrencyPastRttMean
The mean round-trip time (RTT) from past windows, used as the baseline for adaptive concurrency decisions.
AdaptiveConcurrencyReachedLimit
A boolean sample (1.0 if the concurrency limit was reached during the most recent limit update, 0.0 otherwise).
S3ObjectProcessingSucceededDurationSeconds
The time taken to process an S3 object that succeeded, in seconds.
S3ObjectProcessingFailedDurationSeconds
The time taken to process an S3 object that failed, in seconds.
CollectDurationSeconds
The duration spent collecting metrics for this component.
CommandExecutionDurationSeconds
The command execution duration in seconds.
GrpcServerHandlerDurationSeconds
The duration spent handling a gRPC request.
HttpServerHandlerDurationSeconds
The duration spent handling an HTTP request.
HttpClientRttSeconds
The round-trip time (RTT) of HTTP requests.
HttpClientResponseRttSeconds
The round-trip time (RTT) of HTTP requests, tagged with the response code.
HttpClientErrorRttSeconds
The round-trip time (RTT) of HTTP requests that resulted in an error.
SourceBufferUtilization
The utilization level of the source buffer. The outputs of the source send data to this buffer.
TransformBufferUtilization
The utilization level of the buffer that feeds into a transform.
Implementations